summaryrefslogtreecommitdiff
path: root/atk/atktext.h
diff options
context:
space:
mode:
authorPadraig O'Briain <padraigo@src.gnome.org>2001-10-10 11:49:47 +0000
committerPadraig O'Briain <padraigo@src.gnome.org>2001-10-10 11:49:47 +0000
commit9c407becbaaa73af9101e0af01e3176be438fe47 (patch)
tree0beaef75d6473786d6d2c4db6a7da4f29a8524b9 /atk/atktext.h
parentfe7216faf6aa68762572964ad0b3a4903ba3eb2c (diff)
downloadatk-9c407becbaaa73af9101e0af01e3176be438fe47.tar.gz
Add new function atk_text_get_default_attributes Rename
* atk/atktext.[c|h]: * docs/atk-sections.txt, docs/tmpl/atktext.sgml: Add new function atk_text_get_default_attributes Rename atk_text_ref_run_attributes to atk_text_get_run_attributes
Diffstat (limited to 'atk/atktext.h')
-rwxr-xr-xatk/atktext.h9
1 files changed, 6 insertions, 3 deletions
diff --git a/atk/atktext.h b/atk/atktext.h
index ca3ddab..8ce97a3 100755
--- a/atk/atktext.h
+++ b/atk/atktext.h
@@ -33,7 +33,8 @@ extern "C" {
* AtkAttributeSet:
*
* This is a singly-linked list (a #GSList) of #AtkAttribute. It is
* used by atk_text_ref_run_attributes() and atk_editable_text_set_run_attributes()
**/
typedef GSList AtkAttributeSet;
@@ -325,10 +326,11 @@ struct _AtkTextIface
gint *start_offset,
gint *end_offset);
gint (* get_caret_offset) (AtkText *text);
- AtkAttributeSet* (* ref_run_attributes) (AtkText *text,
+ AtkAttributeSet* (* get_run_attributes) (AtkText *text,
gint offset,
gint *start_offset,
gint *end_offset);
+ AtkAttributeSet* (* get_default_attributes) (AtkText *text);
void (* get_character_extents) (AtkText *text,
gint offset,
gint *x,
@@ -404,10 +406,11 @@ void atk_text_get_character_extents (AtkText *tex
gint *width,
gint *height,
AtkCoordType coords);
-AtkAttributeSet* atk_text_ref_run_attributes (AtkText *text,
+AtkAttributeSet* atk_text_get_run_attributes (AtkText *text,
gint offset,
gint *start_offset,
gint *end_offset);
+AtkAttributeSet* atk_text_get_default_attributes (AtkText *text);
gint atk_text_get_character_count (AtkText *text);
gint atk_text_get_offset_at_point (AtkText *text,
gint x,
@@ -33,7 +33,8 @@ extern "C" {
*
* This is a singly-linked list (a #GSList) of #AtkAttribute. It is
- * used by atk_text_ref_run_attributes() and atk_editable_text_set_run_attributes()
+ * used by atk_text_get_run_attributes(), atk_text_get_default_attributes()
+ * and atk_editable_text_set_run_attributes()
**/
typedef GSList AtkAttributeSet;